@@ -28,16 +28,16 @@ class HazeGroupWiseAccountUi : public AbstractAccountUi
     Q_OBJECT
 
 public:
-    explicit HazeGroupWiseAccountUi(QObject *parent = 0);
-    virtual ~HazeGroupWiseAccountUi();
+    explicit HazeGroupWiseAccountUi(QObject *parent = nullptr);
+    ~HazeGroupWiseAccountUi() override;
 
-    virtual AbstractAccountParametersWidget
+    AbstractAccountParametersWidget
               *mainOptionsWidget(ParameterEditModel *model,
-                                 QWidget *parent = 0) const override;
-    virtual bool hasAdvancedOptionsWidget() const override;
-    virtual AbstractAccountParametersWidget
+                                 QWidget *parent = nullptr) const override;
+    bool hasAdvancedOptionsWidget() const override;
+    AbstractAccountParametersWidget
               *advancedOptionsWidget(ParameterEditModel *model,
-                                     QWidget *parent = 0) const override;
+                                     QWidget *parent = nullptr) const override;
 
 private:
     Q_DISABLE_COPY(HazeGroupWiseAccountUi)
